@@ -1,7 +1,7 @@
 
-RProtoBuf_new <- if (requireNamespace('RProtoBuf')) RProtoBuf::new
-RProtoBuf_serialize <- if (requireNamespace('RProtoBuf')) RProtoBuf::serialize
-RProtoBuf_read <- if (requireNamespace('RProtoBuf')) RProtoBuf::read
+RProtoBuf_new <- if (requireNamespace('RProtoBuf', quietly=TRUE)) RProtoBuf::new
+RProtoBuf_serialize <- if (requireNamespace('RProtoBuf', quietly=TRUE)) RProtoBuf::serialize
+RProtoBuf_read <- if (requireNamespace('RProtoBuf', quietly=TRUE)) RProtoBuf::read
 
 initProtoBuf <- function() {
     if ( ! exists('jamovi.coms.Status')) {
@@ -11,7 +11,9 @@ initProtoBuf <- function() {
         if (resultsProtoPath == "")
             stop("jmvcore jamovi.proto not found!", call.=FALSE)
 
-        if (requireNamespace('RProtoBuf'))
+        if (requireNamespace('RProtoBuf', quietly=TRUE))
             RProtoBuf::readProtoFiles(resultsProtoPath)
+        else
+            stop('Could not load RProtoBuf')
     }
 }
